@@ -1,5 +1,11 @@
+import sys
 from enum import Enum
-from typing import List, TypedDict
+from typing import List
+
+if sys.version_info >= (3, 8):
+    from typing import TypedDict
+else:
+    from typing_extensions import TypedDict
 
 
 class Period(Enum):
